DROP DATABASE IF EXISTS sportveranstaltung;
CREATE DATABASE IF NOT EXISTS sportveranstaltung;

USE sportveranstaltung


DROP TABLE IF EXISTS tbl_geschlecht;
CREATE TABLE tbl_geschlecht(
pk_geschlecht CHAR(1) NOT NULL PRIMARY KEY 
)
ENGINE = InnoDB;

DROP TABLE IF EXISTS tbl_position;
CREATE TABLE tbl_position (
pk_position VARCHAR(20) NOT NULL PRIMARY KEY
)
ENGINE = InnoDB;

DROP TABLE IF EXISTS tbl_veranstaltungsort;
CREATE TABLE tbl_veranstaltungsort (
pk_id_veranstaltungsort INT AUTO_INCREMENT NOT NULL PRIMARY KEY,
ort VARCHAR(20) NOT NULL,
plz CHAR(5) NOT NULL,
straße VARCHAR(20) NOT NULL,
hausnummer VARCHAR(4) NOT NULL
)
ENGINE = InnoDB;

DROP TABLE IF EXISTS tbl_sponsoren;
CREATE TABLE tbl_sponsoren (
pk_sponsoren_id INT AUTO_INCREMENT NOT NULL PRIMARY KEY,
sponsorenname VARCHAR(45) NOT NULL,
ort VARCHAR(20) NOT NULL,
plz CHAR(5) NOT NULL,
straße VARCHAR(20),
hausnummer VARCHAR(4),
telefon VARCHAR(20) NOT NULL,
email VARCHAR(60) NOT NULL
)
ENGINE = InnoDB;


DROP TABLE IF EXISTS tbl_sportart;
CREATE TABLE tbl_sportart (
pk_sportart VARCHAR(45) NOT NULL PRIMARY KEY
)
ENGINE = InnoDB;

DROP TABLE IF EXISTS tbl_altersklasse;
CREATE TABLE tbl_altersklasse(
pk_altersklasse VARCHAR(5) NOT NULL PRIMARY KEY
)
ENGINE = InnoDB;

DROP TABLE IF EXISTS tbl_nation;
CREATE TABLE tbl_nation (
pk_nation VARCHAR(30) NOT NULL PRIMARY KEY
)
ENGINE = InnoDB;

DROP TABLE IF EXISTS tbl_verein;
CREATE TABLE tbl_verein (
pk_id_verein INT AUTO_INCREMENT NOT NULL PRIMARY KEY,
verein VARCHAR(45) NOT NULL,
ort VARCHAR(20) NOT NULL,
plz CHAR(5) NOT NULL,
straße VARCHAR(20),
hausnummer VARCHAR(4),
telefon VARCHAR(20) NOT NULL,
email VARCHAR(60) NOT NULL
)
ENGINE = InnoDB;

DROP TABLE IF EXISTS tbl_accountdaten;
CREATE TABLE tbl_accountdaten (
pk_username VARCHAR(20) NOT NULL PRIMARY KEY,
password VARCHAR(32) NOT NULL
)
ENGINE = InnoDB;

DROP TABLE IF EXISTS tbl_mitarbeiter;
CREATE TABLE tbl_mitarbeiter (
pk_id_mitarbeiter INT AUTO_INCREMENT NOT NULL PRIMARY KEY,
vorname VARCHAR(20) NOT NULL,
nachname VARCHAR(20) NOT NULL,
ort VARCHAR(20) NOT NULL,
plz CHAR(5) NOT NULL,
straße VARCHAR(20) NOT NULL,
hausnummer VARCHAR(4) NOT NULL,
telefon VARCHAR(20) NOT NULL,
email VARCHAR(60) NOT NULL,
geburtsdatum DATE NOT NULL,
fk_username VARCHAR(20) NOT NULL,
fk_geschlecht CHAR(1) NOT NULL,
fk_nation VARCHAR(30) NOT NULL,
fk_position VARCHAR(20) NOT NULL,
INDEX fk_username(fk_username),

FOREIGN KEY(fk_username)
	REFERENCES tbl_accountdaten(pk_username)
		ON UPDATE CASCADE
		ON DELETE NO ACTION,

INDEX fk_nation(fk_nation),
			
FOREIGN KEY(fk_nation)
	REFERENCES tbl_nation(pk_nation)
		ON UPDATE CASCADE
		ON DELETE NO ACTION,
	
INDEX fk_geschlecht(fk_geschlecht),

FOREIGN KEY(fk_geschlecht)
	REFERENCES tbl_geschlecht(pk_geschlecht)
		ON UPDATE CASCADE
		ON DELETE NO ACTION,
		
INDEX fk_position(fk_position),
			
FOREIGN KEY(fk_position)
	REFERENCES tbl_position(pk_position)
		ON UPDATE CASCADE
		ON DELETE NO ACTION
)
ENGINE = InnoDB;

DROP TABLE IF EXISTS tbl_sportler;
CREATE TABLE tbl_sportler (
pk_id_sportler INT AUTO_INCREMENT NOT NULL PRIMARY KEY,
vorname VARCHAR(20) NOT NULL,
nachname VARCHAR(20) NOT NULL,
ort VARCHAR(20),
plz CHAR(5),
straße VARCHAR(20),
hausnummer VARCHAR(4),
telefon VARCHAR(20) NOT NULL,
email VARCHAR(60) NOT NULL,
geburtsdatum DATE NOT NULL,
fk_username VARCHAR(20) NOT NULL,
fk_nation VARCHAR(30) NOT NULL,
fk_geschlecht VARCHAR(15) NOT NULL,

INDEX fk_username(fk_username),

FOREIGN KEY(fk_username)
	REFERENCES tbl_accountdaten(pk_username)
		ON UPDATE CASCADE
		ON DELETE NO ACTION,
			
INDEX fk_nation(fk_nation),
			
FOREIGN KEY(fk_nation)
	REFERENCES tbl_nation(pk_nation)
		ON UPDATE CASCADE
		ON DELETE NO ACTION,
			
INDEX fk_geschlecht(fk_geschlecht),
			
FOREIGN KEY(fk_geschlecht)
	REFERENCES tbl_geschlecht(pk_geschlecht)
		ON UPDATE CASCADE
		ON DELETE NO ACTION
)
ENGINE = InnoDB;

DROP TABLE IF EXISTS tbl_sportveranstaltung;
CREATE TABLE tbl_sportveranstaltung (
pk_id_sportveranstaltung INT AUTO_INCREMENT NOT NULL PRIMARY KEY,
veranstaltungsname VARCHAR(80) NOT NULL,
termin DATE NOT NULL,
fk_id_veranstaltungsort INT NOT NULL,
fk_id_mitarbeiter INT NOT NULL,
fk_sportart VARCHAR(45) NOT NULL,

INDEX fk_id_veranstaltungsort(fk_id_veranstaltungsort),

FOREIGN KEY(fk_id_veranstaltungsort)
	REFERENCES tbl_veranstaltungsort(pk_id_veranstaltungsort)
		ON UPDATE CASCADE
		ON DELETE NO ACTION,

INDEX fk_id_mitarbeiter(fk_id_mitarbeiter),		
			
FOREIGN KEY(fk_id_mitarbeiter)
		REFERENCES tbl_mitarbeiter(pk_id_mitarbeiter)
			ON UPDATE CASCADE
			ON DELETE NO ACTION,
			
INDEX fk_sportart(fk_sportart),
			
FOREIGN KEY(fk_sportart)
	REFERENCES tbl_sportart(pk_sportart)
		ON UPDATE CASCADE
		ON DELETE NO ACTION
)
ENGINE = InnoDB;


DROP TABLE IF EXISTS tbl_teilnahme;
CREATE TABLE tbl_teilnahme(
pk_fk_id_sportler INT NOT NULL,
pk_fk_id_sportveranstaltung INT NOT NULL,
startnummer VARCHAR(6),
platz VARCHAR(6),
akplatz VARCHAR(6),
mwplatz VARCHAR(6),
zeit time,
fk_id_verein INT NOT NULL,
fk_altersklasse VARCHAR(5) NOT NULL,
PRIMARY KEY(pk_fk_id_sportler ,pk_fk_id_sportveranstaltung),
INDEX pk_fk_id_sportler(pk_fk_id_sportler),

FOREIGN KEY(pk_fk_id_sportler)
	REFERENCES tbl_sportler(pk_id_sportler)
		ON UPDATE CASCADE
		ON DELETE NO ACTION,

INDEX pk_fk_id_sportveranstaltung(pk_fk_id_sportveranstaltung),		
		
FOREIGN KEY(pk_fk_id_sportveranstaltung)
	REFERENCES tbl_sportveranstaltung(pk_id_sportveranstaltung)
		ON UPDATE CASCADE
		ON DELETE NO ACTION,

INDEX fk_id_verein(fk_id_verein),		
		
FOREIGN KEY(fk_id_verein)
	REFERENCES tbl_verein(pk_id_verein)
		ON UPDATE CASCADE
		ON DELETE NO ACTION,
			
INDEX fk_altersklasse(fk_altersklasse),			
			
FOREIGN KEY(fk_altersklasse)
	REFERENCES tbl_altersklasse(pk_altersklasse)
		ON UPDATE CASCADE
		ON DELETE NO ACTION


)
ENGINE = InnoDB;

DROP TABLE IF EXISTS tbl_veranstaltung_sponsor;
CREATE TABLE tbl_veranstaltung_sponsor (
pk_fk_id_sponsoren INT NOT NULL,
pk_fk_id_sportveranstaltung INT NOT NULL,

PRIMARY KEY (pk_fk_id_sponsoren,pk_fk_id_sportveranstaltung),
	
INDEX pk_fk_id_sponsoren(pk_fk_id_sponsoren),	
	
FOREIGN KEY(pk_fk_id_sponsoren)
	REFERENCES tbl_sponsoren(pk_sponsoren_id)
		ON UPDATE CASCADE
		ON DELETE NO ACTION,
			
INDEX pk_fk_id_sportveranstaltung(pk_fk_id_sportveranstaltung),
			
FOREIGN KEY(pk_fk_id_sportveranstaltung)
	REFERENCES tbl_sportveranstaltung(pk_id_sportveranstaltung)
		ON UPDATE CASCADE
		ON DELETE NO ACTION
			
)
ENGINE = InnoDB;

INSERT INTO tbl_geschlecht VALUES ('m'),('w');

LOAD DATA LOCAL INFILE 'F:/xampp/htdocs/sportveranstaltung/dbundscriptserm/position.txt' INTO TABLE tbl_position FIELDS TERMINATED BY ';' LINES TERMINATED BY '\r\n';

LOAD DATA LOCAL INFILE 'F:/xampp/htdocs/sportveranstaltung/dbundscriptserm/veranstaltungsort.csv' INTO TABLE tbl_veranstaltungsort FIELDS TERMINATED BY ';' LINES TERMINATED BY '\r\n';

LOAD DATA LOCAL INFILE 'F:/xampp/htdocs/sportveranstaltung/dbundscriptserm/sponsor.csv'  INTO TABLE tbl_sponsoren FIELDS TERMINATED BY ';' LINES TERMINATED BY '\r\n';

LOAD DATA LOCAL INFILE 'F:/xampp/htdocs/sportveranstaltung/dbundscriptserm/sportart.csv' INTO TABLE tbl_sportart FIELDS TERMINATED BY ';' LINES TERMINATED BY '\r\n';

LOAD DATA LOCAL INFILE 'F:/xampp/htdocs/sportveranstaltung/dbundscriptserm/altersklasse.txt' INTO TABLE tbl_altersklasse FIELDS TERMINATED BY ';' LINES TERMINATED BY '\r\n';

LOAD DATA LOCAL INFILE 'F:/xampp/htdocs/sportveranstaltung/dbundscriptserm/nation.csv' INTO TABLE tbl_nation FIELDS TERMINATED BY ';' LINES TERMINATED BY '\r\n';

LOAD DATA LOCAL INFILE 'F:/xampp/htdocs/sportveranstaltung/dbundscriptserm/verein.csv' INTO TABLE tbl_verein FIELDS TERMINATED BY ';' LINES TERMINATED BY '\r\n';

SOURCE F:/xampp/htdocs/sportveranstaltung/dbundscriptserm/accountdaten.sql;

LOAD DATA LOCAL INFILE 'F:/xampp/htdocs/sportveranstaltung/dbundscriptserm/mitarbeiter.csv' INTO TABLE tbl_mitarbeiter FIELDS TERMINATED BY ';' LINES TERMINATED BY '\r\n';

LOAD DATA LOCAL INFILE 'F:/xampp/htdocs/sportveranstaltung/dbundscriptserm/sportler.csv' INTO TABLE tbl_sportler FIELDS TERMINATED BY ';' LINES TERMINATED BY '\r\n';

LOAD DATA LOCAL INFILE 'F:/xampp/htdocs/sportveranstaltung/dbundscriptserm/sportveranstaltung.csv' INTO TABLE tbl_sportveranstaltung FIELDS TERMINATED BY ';' LINES TERMINATED BY '\r\n';

LOAD DATA LOCAL INFILE 'F:/xampp/htdocs/sportveranstaltung/dbundscriptserm/teilnahme.csv' INTO TABLE tbl_teilnahme FIELDS TERMINATED BY ';' LINES TERMINATED BY '\r\n';

LOAD DATA LOCAL INFILE 'F:/xampp/htdocs/sportveranstaltung/dbundscriptserm/sponsoren_veranstaltung.csv' INTO TABLE tbl_veranstaltung_sponsor FIELDS TERMINATED BY ';' LINES TERMINATED BY '\r\n';